# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/label_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/label_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\017LabelErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n6google/ads/googleads_v1/proto/errors/label_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\x96\x03\n\x0eLabelErrorEnum\"\x83\x03\n\nLabelError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1f\n\x1b\x43\x41NNOT_APPLY_INACTIVE_LABEL\x10\x02\x12\x35\n1CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION\x10\x03\x12\x35\n1CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION\x10\x04\x12!\n\x1d\x45XCEEDED_LABEL_LIMIT_PER_TYPE\x10\x05\x12&\n\"INVALID_RESOURCE_FOR_MANAGER_LABEL\x10\x06\x12\x12\n\x0e\x44UPLICATE_NAME\x10\x07\x12\x16\n\x12INVALID_LABEL_NAME\x10\x08\x12 \n\x1c\x43\x41NNOT_ATTACH_LABEL_TO_DRAFT\x10\t\x12/\n+CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER\x10\nB\xea\x01\n\"com.google.ads.googleads.v1.errorsB\x0fLabelErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_LABELERRORENUM_LABELERROR = _descriptor.EnumDescriptor(
  name='LabelError',
  full_name='google.ads.googleads.v1.errors.LabelErrorEnum.LabelError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_APPLY_INACTIVE_LABEL', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_APPLY_LABEL_TO_DISABLED_AD_GROUP_CRITERION', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_APPLY_LABEL_TO_NEGATIVE_AD_GROUP_CRITERION', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='EXCEEDED_LABEL_LIMIT_PER_TYPE', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_RESOURCE_FOR_MANAGER_LABEL', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DUPLICATE_NAME', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_LABEL_NAME', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ATTACH_LABEL_TO_DRAFT', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='CANNOT_ATTACH_NON_MANAGER_LABEL_TO_CUSTOMER', index=10, number=10,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=140,
  serialized_end=527,
)
_sym_db.RegisterEnumDescriptor(_LABELERRORENUM_LABELERROR)


_LABELERRORENUM = _descriptor.Descriptor(
  name='LabelErrorEnum',
  full_name='google.ads.googleads.v1.errors.LabelErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _LABELERRORENUM_LABELERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=121,
  serialized_end=527,
)

_LABELERRORENUM_LABELERROR.containing_type = _LABELERRORENUM
DESCRIPTOR.message_types_by_name['LabelErrorEnum'] = _LABELERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

LabelErrorEnum = _reflection.GeneratedProtocolMessageType('LabelErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _LABELERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.label_error_pb2'
  ,
  __doc__ = """Container for enum describing possible label errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.LabelErrorEnum)
  ))
_sym_db.RegisterMessage(LabelErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import remarketing_action_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_remarketing__action__pb2
from google.ads.google_ads.v2.proto.services import remarketing_action_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2


class RemarketingActionServiceStub(object):
  """Proto file describing the Remarketing Action service.

  Service to manage remarketing actions.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetRemarketingAction = channel.unary_unary(
        '/google.ads.googleads.v2.services.RemarketingActionService/GetRemarketingAction',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.GetRemarketingActionRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_remarketing__action__pb2.RemarketingAction.FromString,
        )
    self.MutateRemarketingActions = channel.unary_unary(
        '/google.ads.googleads.v2.services.RemarketingActionService/MutateRemarketingActions',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.MutateRemarketingActionsRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.MutateRemarketingActionsResponse.FromString,
        )


class RemarketingActionServiceServicer(object):
  """Proto file describing the Remarketing Action service.

  Service to manage remarketing actions.
  """

  def GetRemarketingAction(self, request, context):
    """Returns the requested remarketing action in full detail.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')

  def MutateRemarketingActions(self, request, context):
    """Creates or updates remarketing actions. Operation statuses are returned.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_RemarketingActionServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetRemarketingAction': grpc.unary_unary_rpc_method_handler(
          servicer.GetRemarketingAction,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.GetRemarketingActionRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_remarketing__action__pb2.RemarketingAction.SerializeToString,
      ),
      'MutateRemarketingActions': grpc.unary_unary_rpc_method_handler(
          servicer.MutateRemarketingActions,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.MutateRemarketingActionsRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_remarketing__action__service__pb2.MutateRemarketingActionsResponse.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.RemarketingActionService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/common/value.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/common/value.proto',
  package='google.ads.googleads.v2.common',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.commonB\nValueProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Common\312\002\036Google\\Ads\\GoogleAds\\V2\\Common\352\002\"Google::Ads::GoogleAds::V2::Common'),
  serialized_pb=_b('\n0google/ads/googleads_v2/proto/common/value.proto\x12\x1egoogle.ads.googleads.v2.common\x1a\x1cgoogle/api/annotations.proto\"\x87\x01\n\x05Value\x12\x17\n\rboolean_value\x18\x01 \x01(\x08H\x00\x12\x15\n\x0bint64_value\x18\x02 \x01(\x03H\x00\x12\x15\n\x0b\x66loat_value\x18\x03 \x01(\x02H\x00\x12\x16\n\x0c\x64ouble_value\x18\x04 \x01(\x01H\x00\x12\x16\n\x0cstring_value\x18\x05 \x01(\tH\x00\x42\x07\n\x05valueB\xe5\x01\n\"com.google.ads.googleads.v2.commonB\nValueProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/common;common\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Common\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Common\xea\x02\"Google::Ads::GoogleAds::V2::Commonb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_VALUE = _descriptor.Descriptor(
  name='Value',
  full_name='google.ads.googleads.v2.common.Value',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='boolean_value', full_name='google.ads.googleads.v2.common.Value.boolean_value', index=0,
      number=1, type=8, cpp_type=7, label=1,
      has_default_value=False, default_value=False,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='int64_value', full_name='google.ads.googleads.v2.common.Value.int64_value', index=1,
      number=2, type=3, cpp_type=2, label=1,
      has_default_value=False, default_value=0,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='float_value', full_name='google.ads.googleads.v2.common.Value.float_value', index=2,
      number=3, type=2, cpp_type=6, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='double_value', full_name='google.ads.googleads.v2.common.Value.double_value', index=3,
      number=4, type=1, cpp_type=5, label=1,
      has_default_value=False, default_value=float(0),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='string_value', full_name='google.ads.googleads.v2.common.Value.string_value', index=4,
      number=5, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='value', full_name='google.ads.googleads.v2.common.Value.value',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=115,
  serialized_end=250,
)

_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['boolean_value'])
_VALUE.fields_by_name['boolean_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['int64_value'])
_VALUE.fields_by_name['int64_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['float_value'])
_VALUE.fields_by_name['float_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['double_value'])
_VALUE.fields_by_name['double_value'].containing_oneof = _VALUE.oneofs_by_name['value']
_VALUE.oneofs_by_name['value'].fields.append(
  _VALUE.fields_by_name['string_value'])
_VALUE.fields_by_name['string_value'].containing_oneof = _VALUE.oneofs_by_name['value']
DESCRIPTOR.message_types_by_name['Value'] = _VALUE
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

Value = _reflection.GeneratedProtocolMessageType('Value', (_message.Message,), dict(
  DESCRIPTOR = _VALUE,
  __module__ = 'google.ads.googleads_v2.proto.common.value_pb2'
  ,
  __doc__ = """A generic data container.
  
  
  Attributes:
      value:
          A value.
      boolean_value:
          A boolean.
      int64_value:
          An int64.
      float_value:
          A float.
      double_value:
          A double.
      string_value:
          A string.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.common.Value)
  ))
_sym_db.RegisterMessage(Value)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# Generated by the gRPC Python protocol compiler plugin. DO NOT EDIT!
import grpc

from google.ads.google_ads.v2.proto.resources import language_constant_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_language__constant__pb2
from google.ads.google_ads.v2.proto.services import language_constant_service_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_language__constant__service__pb2


class LanguageConstantServiceStub(object):
  """Proto file describing the language constant service.

  Service to fetch language constants.
  """

  def __init__(self, channel):
    """Constructor.

    Args:
      channel: A grpc.Channel.
    """
    self.GetLanguageConstant = channel.unary_unary(
        '/google.ads.googleads.v2.services.LanguageConstantService/GetLanguageConstant',
        request_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_language__constant__service__pb2.GetLanguageConstantRequest.SerializeToString,
        response_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_language__constant__pb2.LanguageConstant.FromString,
        )


class LanguageConstantServiceServicer(object):
  """Proto file describing the language constant service.

  Service to fetch language constants.
  """

  def GetLanguageConstant(self, request, context):
    """Returns the requested language constant.
    """
    context.set_code(grpc.StatusCode.UNIMPLEMENTED)
    context.set_details('Method not implemented!')
    raise NotImplementedError('Method not implemented!')


def add_LanguageConstantServiceServicer_to_server(servicer, server):
  rpc_method_handlers = {
      'GetLanguageConstant': grpc.unary_unary_rpc_method_handler(
          servicer.GetLanguageConstant,
          request_deserializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_services_dot_language__constant__service__pb2.GetLanguageConstantRequest.FromString,
          response_serializer=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_language__constant__pb2.LanguageConstant.SerializeToString,
      ),
  }
  generic_handler = grpc.method_handlers_generic_handler(
      'google.ads.googleads.v2.services.LanguageConstantService', rpc_method_handlers)
  server.add_generic_rpc_handlers((generic_handler,))



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/enums/distance_bucket.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/enums/distance_bucket.proto',
  package='google.ads.googleads.v2.enums',
  syntax='proto3',
  serialized_options=_b('\n!com.google.ads.googleads.v2.enumsB\023DistanceBucketProtoP\001ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\242\002\003GAA\252\002\035Google.Ads.GoogleAds.V2.Enums\312\002\035Google\\Ads\\GoogleAds\\V2\\Enums\352\002!Google::Ads::GoogleAds::V2::Enums'),
  serialized_pb=_b('\n9google/ads/googleads_v2/proto/enums/distance_bucket.proto\x12\x1dgoogle.ads.googleads.v2.enums\x1a\x1cgoogle/api/annotations.proto\"\xad\x04\n\x12\x44istanceBucketEnum\"\x96\x04\n\x0e\x44istanceBucket\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x0f\n\x0bWITHIN_700M\x10\x02\x12\x0e\n\nWITHIN_1KM\x10\x03\x12\x0e\n\nWITHIN_5KM\x10\x04\x12\x0f\n\x0bWITHIN_10KM\x10\x05\x12\x0f\n\x0bWITHIN_15KM\x10\x06\x12\x0f\n\x0bWITHIN_20KM\x10\x07\x12\x0f\n\x0bWITHIN_25KM\x10\x08\x12\x0f\n\x0bWITHIN_30KM\x10\t\x12\x0f\n\x0bWITHIN_35KM\x10\n\x12\x0f\n\x0bWITHIN_40KM\x10\x0b\x12\x0f\n\x0bWITHIN_45KM\x10\x0c\x12\x0f\n\x0bWITHIN_50KM\x10\r\x12\x0f\n\x0bWITHIN_55KM\x10\x0e\x12\x0f\n\x0bWITHIN_60KM\x10\x0f\x12\x0f\n\x0bWITHIN_65KM\x10\x10\x12\x0f\n\x0b\x42\x45YOND_65KM\x10\x11\x12\x13\n\x0fWITHIN_0_7MILES\x10\x12\x12\x10\n\x0cWITHIN_1MILE\x10\x13\x12\x11\n\rWITHIN_5MILES\x10\x14\x12\x12\n\x0eWITHIN_10MILES\x10\x15\x12\x12\n\x0eWITHIN_15MILES\x10\x16\x12\x12\n\x0eWITHIN_20MILES\x10\x17\x12\x12\n\x0eWITHIN_25MILES\x10\x18\x12\x12\n\x0eWITHIN_30MILES\x10\x19\x12\x12\n\x0eWITHIN_35MILES\x10\x1a\x12\x12\n\x0eWITHIN_40MILES\x10\x1b\x12\x12\n\x0e\x42\x45YOND_40MILES\x10\x1c\x42\xe8\x01\n!com.google.ads.googleads.v2.enumsB\x13\x44istanceBucketProtoP\x01ZBgoogle.golang.org/genproto/googleapis/ads/googleads/v2/enums;enums\xa2\x02\x03GAA\xaa\x02\x1dGoogle.Ads.GoogleAds.V2.Enums\xca\x02\x1dGoogle\\Ads\\GoogleAds\\V2\\Enums\xea\x02!Google::Ads::GoogleAds::V2::Enumsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_DISTANCEBUCKETENUM_DISTANCEBUCKET = _descriptor.EnumDescriptor(
  name='DistanceBucket',
  full_name='google.ads.googleads.v2.enums.DistanceBucketEnum.DistanceBucket',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_700M', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_1KM', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_5KM', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_10KM', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_15KM', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_20KM', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_25KM', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_30KM', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_35KM', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_40KM', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_45KM', index=12, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_50KM', index=13, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_55KM', index=14, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_60KM', index=15, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_65KM', index=16, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BEYOND_65KM', index=17, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_0_7MILES', index=18, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_1MILE', index=19, number=19,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_5MILES', index=20, number=20,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_10MILES', index=21, number=21,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_15MILES', index=22, number=22,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_20MILES', index=23, number=23,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_25MILES', index=24, number=24,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_30MILES', index=25, number=25,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_35MILES', index=26, number=26,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='WITHIN_40MILES', index=27, number=27,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BEYOND_40MILES', index=28, number=28,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=146,
  serialized_end=680,
)
_sym_db.RegisterEnumDescriptor(_DISTANCEBUCKETENUM_DISTANCEBUCKET)


_DISTANCEBUCKETENUM = _descriptor.Descriptor(
  name='DistanceBucketEnum',
  full_name='google.ads.googleads.v2.enums.DistanceBucketEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _DISTANCEBUCKETENUM_DISTANCEBUCKET,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=680,
)

_DISTANCEBUCKETENUM_DISTANCEBUCKET.containing_type = _DISTANCEBUCKETENUM
DESCRIPTOR.message_types_by_name['DistanceBucketEnum'] = _DISTANCEBUCKETENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

DistanceBucketEnum = _reflection.GeneratedProtocolMessageType('DistanceBucketEnum', (_message.Message,), dict(
  DESCRIPTOR = _DISTANCEBUCKETENUM,
  __module__ = 'google.ads.googleads_v2.proto.enums.distance_bucket_pb2'
  ,
  __doc__ = """Container for distance buckets of a user’s distance from an advertiser’s
  location extension.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.enums.DistanceBucketEnum)
  ))
_sym_db.RegisterMessage(DistanceBucketEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/resources/payments_account.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.protobuf import wrappers_pb2 as google_dot_protobuf_dot_wrappers__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/resources/payments_account.proto',
  package='google.ads.googleads.v2.resources',
  syntax='proto3',
  serialized_options=_b('\n%com.google.ads.googleads.v2.resourcesB\024PaymentsAccountProtoP\001ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\242\002\003GAA\252\002!Google.Ads.GoogleAds.V2.Resources\312\002!Google\\Ads\\GoogleAds\\V2\\Resources\352\002%Google::Ads::GoogleAds::V2::Resources'),
  serialized_pb=_b('\n>google/ads/googleads_v2/proto/resources/payments_account.proto\x12!google.ads.googleads.v2.resources\x1a\x1egoogle/protobuf/wrappers.proto\x1a\x1cgoogle/api/annotations.proto\"\xc4\x02\n\x0fPaymentsAccount\x12\x15\n\rresource_name\x18\x01 \x01(\t\x12\x39\n\x13payments_account_id\x18\x02 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12*\n\x04name\x18\x03 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x33\n\rcurrency_code\x18\x04 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x39\n\x13payments_profile_id\x18\x05 \x01(\x0b\x32\x1c.google.protobuf.StringValue\x12\x43\n\x1dsecondary_payments_profile_id\x18\x06 \x01(\x0b\x32\x1c.google.protobuf.StringValueB\x81\x02\n%com.google.ads.googleads.v2.resourcesB\x14PaymentsAccountProtoP\x01ZJgoogle.golang.org/genproto/googleapis/ads/googleads/v2/resources;resources\xa2\x02\x03GAA\xaa\x02!Google.Ads.GoogleAds.V2.Resources\xca\x02!Google\\Ads\\GoogleAds\\V2\\Resources\xea\x02%Google::Ads::GoogleAds::V2::Resourcesb\x06proto3')
  ,
  dependencies=[google_dot_protobuf_dot_wrappers__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,])




_PAYMENTSACCOUNT = _descriptor.Descriptor(
  name='PaymentsAccount',
  full_name='google.ads.googleads.v2.resources.PaymentsAccount',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.resources.PaymentsAccount.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_account_id', full_name='google.ads.googleads.v2.resources.PaymentsAccount.payments_account_id', index=1,
      number=2, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='name', full_name='google.ads.googleads.v2.resources.PaymentsAccount.name', index=2,
      number=3, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='currency_code', full_name='google.ads.googleads.v2.resources.PaymentsAccount.currency_code', index=3,
      number=4, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='payments_profile_id', full_name='google.ads.googleads.v2.resources.PaymentsAccount.payments_profile_id', index=4,
      number=5, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='secondary_payments_profile_id', full_name='google.ads.googleads.v2.resources.PaymentsAccount.secondary_payments_profile_id', index=5,
      number=6, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=164,
  serialized_end=488,
)

_PAYMENTSACCOUNT.fields_by_name['payments_account_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PAYMENTSACCOUNT.fields_by_name['name'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PAYMENTSACCOUNT.fields_by_name['currency_code'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PAYMENTSACCOUNT.fields_by_name['payments_profile_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
_PAYMENTSACCOUNT.fields_by_name['secondary_payments_profile_id'].message_type = google_dot_protobuf_dot_wrappers__pb2._STRINGVALUE
DESCRIPTOR.message_types_by_name['PaymentsAccount'] = _PAYMENTSACCOUNT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

PaymentsAccount = _reflection.GeneratedProtocolMessageType('PaymentsAccount', (_message.Message,), dict(
  DESCRIPTOR = _PAYMENTSACCOUNT,
  __module__ = 'google.ads.googleads_v2.proto.resources.payments_account_pb2'
  ,
  __doc__ = """A payments account, which can be used to set up billing for an Ads
  customer.
  
  
  Attributes:
      resource_name:
          The resource name of the payments account. PaymentsAccount
          resource names have the form:  ``customers/{customer_id}/payme
          ntsAccounts/{payments_account_id}``
      payments_account_id:
          A 16 digit ID used to identify a payments account.
      name:
          The name of the payments account.
      currency_code:
          The currency code of the payments account. A subset of the
          currency codes derived from the ISO 4217 standard is
          supported.
      payments_profile_id:
          A 12 digit ID used to identify the payments profile associated
          with the payments account.
      secondary_payments_profile_id:
          A secondary payments profile ID present in uncommon
          situations, e.g. when a sequential liability agreement has
          been arranged.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.resources.PaymentsAccount)
  ))
_sym_db.RegisterMessage(PaymentsAccount)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/errors/keyword_plan_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/errors/keyword_plan_error.proto',
  package='google.ads.googleads.v2.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v2.errorsB\025KeywordPlanErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V2.Errors\312\002\036Google\\Ads\\GoogleAds\\V2\\Errors\352\002\"Google::Ads::GoogleAds::V2::Errors'),
  serialized_pb=_b('\n=google/ads/googleads_v2/proto/errors/keyword_plan_error.proto\x12\x1egoogle.ads.googleads.v2.errors\x1a\x1cgoogle/api/annotations.proto\"\xc8\x03\n\x14KeywordPlanErrorEnum\"\xaf\x03\n\x10KeywordPlanError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12\x1f\n\x1b\x42ID_MULTIPLIER_OUT_OF_RANGE\x10\x02\x12\x10\n\x0c\x42ID_TOO_HIGH\x10\x03\x12\x0f\n\x0b\x42ID_TOO_LOW\x10\x04\x12\"\n\x1e\x42ID_TOO_MANY_FRACTIONAL_DIGITS\x10\x05\x12\x18\n\x14\x44\x41ILY_BUDGET_TOO_LOW\x10\x06\x12+\n\'DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS\x10\x07\x12\x11\n\rINVALID_VALUE\x10\x08\x12 \n\x1cKEYWORD_PLAN_HAS_NO_KEYWORDS\x10\t\x12\x1c\n\x18KEYWORD_PLAN_NOT_ENABLED\x10\n\x12\x1a\n\x16KEYWORD_PLAN_NOT_FOUND\x10\x0b\x12\x0f\n\x0bMISSING_BID\x10\r\x12\x1b\n\x17MISSING_FORECAST_PERIOD\x10\x0e\x12\x1f\n\x1bINVALID_FORECAST_DATE_RANGE\x10\x0f\x12\x10\n\x0cINVALID_NAME\x10\x10\x42\xf0\x01\n\"com.google.ads.googleads.v2.errorsB\x15KeywordPlanErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v2/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V2.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V2\\Errors\xea\x02\"Google::Ads::GoogleAds::V2::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_KEYWORDPLANERRORENUM_KEYWORDPLANERROR = _descriptor.EnumDescriptor(
  name='KeywordPlanError',
  full_name='google.ads.googleads.v2.errors.KeywordPlanErrorEnum.KeywordPlanError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_MULTIPLIER_OUT_OF_RANGE', index=2, number=2,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_TOO_HIGH', index=3, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_TOO_LOW', index=4, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='BID_TOO_MANY_FRACTIONAL_DIGITS', index=5, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAILY_BUDGET_TOO_LOW', index=6, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DAILY_BUDGET_TOO_MANY_FRACTIONAL_DIGITS', index=7, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_VALUE', index=8, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_PLAN_HAS_NO_KEYWORDS', index=9, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_PLAN_NOT_ENABLED', index=10, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='KEYWORD_PLAN_NOT_FOUND', index=11, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_BID', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MISSING_FORECAST_PERIOD', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_FORECAST_DATE_RANGE', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='INVALID_NAME', index=15, number=16,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=153,
  serialized_end=584,
)
_sym_db.RegisterEnumDescriptor(_KEYWORDPLANERRORENUM_KEYWORDPLANERROR)


_KEYWORDPLANERRORENUM = _descriptor.Descriptor(
  name='KeywordPlanErrorEnum',
  full_name='google.ads.googleads.v2.errors.KeywordPlanErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _KEYWORDPLANERRORENUM_KEYWORDPLANERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=128,
  serialized_end=584,
)

_KEYWORDPLANERRORENUM_KEYWORDPLANERROR.containing_type = _KEYWORDPLANERRORENUM
DESCRIPTOR.message_types_by_name['KeywordPlanErrorEnum'] = _KEYWORDPLANERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

KeywordPlanErrorEnum = _reflection.GeneratedProtocolMessageType('KeywordPlanErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _KEYWORDPLANERRORENUM,
  __module__ = 'google.ads.googleads_v2.proto.errors.keyword_plan_error_pb2'
  ,
  __doc__ = """Container for enum describing possible errors from applying a keyword
  plan resource (keyword plan, keyword plan campaign, keyword plan ad
  group or keyword plan keyword) or KeywordPlanService RPC.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.errors.KeywordPlanErrorEnum)
  ))
_sym_db.RegisterMessage(KeywordPlanErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v1/proto/errors/setting_error.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v1/proto/errors/setting_error.proto',
  package='google.ads.googleads.v1.errors',
  syntax='proto3',
  serialized_options=_b('\n\"com.google.ads.googleads.v1.errorsB\021SettingErrorProtoP\001ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\242\002\003GAA\252\002\036Google.Ads.GoogleAds.V1.Errors\312\002\036Google\\Ads\\GoogleAds\\V1\\Errors\352\002\"Google::Ads::GoogleAds::V1::Errors'),
  serialized_pb=_b('\n8google/ads/googleads_v1/proto/errors/setting_error.proto\x12\x1egoogle.ads.googleads.v1.errors\x1a\x1cgoogle/api/annotations.proto\"\xbe\x08\n\x10SettingErrorEnum\"\xa9\x08\n\x0cSettingError\x12\x0f\n\x0bUNSPECIFIED\x10\x00\x12\x0b\n\x07UNKNOWN\x10\x01\x12!\n\x1dSETTING_TYPE_IS_NOT_AVAILABLE\x10\x03\x12\x30\n,SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN\x10\x04\x12;\n7TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP\x10\x05\x12Q\nMTARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL\x10\x06\x12\\\nXTARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP\x10\x07\x12\x43\n?DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT\x10\x08\x12;\n7DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME\x10\t\x12\x36\n2DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME\x10\n\x12=\n9DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE\x10\x0b\x12>\n:TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN\x10\x0c\x12\x38\n4UNIVERSAL_APP_CAMPAIGN_SETTING_DUPLICATE_DESCRIPTION\x10\r\x12\x42\n>UNIVERSAL_APP_CAMPAIGN_SETTING_DESCRIPTION_LINE_WIDTH_TOO_LONG\x10\x0e\x12<\n8UNIVERSAL_APP_CAMPAIGN_SETTING_APP_ID_CANNOT_BE_MODIFIED\x10\x0f\x12\x38\n4TOO_MANY_YOUTUBE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN\x10\x10\x12\x36\n2TOO_MANY_IMAGE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN\x10\x11\x12\x31\n-MEDIA_INCOMPATIBLE_FOR_UNIVERSAL_APP_CAMPAIGN\x10\x12\x12\x1e\n\x1aTOO_MANY_EXCLAMATION_MARKS\x10\x13\x42\xec\x01\n\"com.google.ads.googleads.v1.errorsB\x11SettingErrorProtoP\x01ZDgoogle.golang.org/genproto/googleapis/ads/googleads/v1/errors;errors\xa2\x02\x03GAA\xaa\x02\x1eGoogle.Ads.GoogleAds.V1.Errors\xca\x02\x1eGoogle\\Ads\\GoogleAds\\V1\\Errors\xea\x02\"Google::Ads::GoogleAds::V1::Errorsb\x06proto3')
  ,
  dependencies=[google_dot_api_dot_annotations__pb2.DESCRIPTOR,])



_SETTINGERRORENUM_SETTINGERROR = _descriptor.EnumDescriptor(
  name='SettingError',
  full_name='google.ads.googleads.v1.errors.SettingErrorEnum.SettingError',
  filename=None,
  file=DESCRIPTOR,
  values=[
    _descriptor.EnumValueDescriptor(
      name='UNSPECIFIED', index=0, number=0,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNKNOWN', index=1, number=1,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SETTING_TYPE_IS_NOT_AVAILABLE', index=2, number=3,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='SETTING_TYPE_IS_NOT_COMPATIBLE_WITH_CAMPAIGN', index=3, number=4,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGETING_SETTING_CONTAINS_INVALID_CRITERION_TYPE_GROUP', index=4, number=5,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGETING_SETTING_DEMOGRAPHIC_CRITERION_TYPE_GROUPS_MUST_BE_SET_TO_TARGET_ALL', index=5, number=6,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGETING_SETTING_CANNOT_CHANGE_TARGET_ALL_TO_FALSE_FOR_DEMOGRAPHIC_CRITERION_TYPE_GROUP', index=6, number=7,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_SEARCH_ADS_SETTING_AT_LEAST_ONE_FEED_ID_MUST_BE_PRESENT', index=7, number=8,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_DOMAIN_NAME', index=8, number=9,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_SUBDOMAIN_NAME', index=9, number=10,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='DYNAMIC_SEARCH_ADS_SETTING_CONTAINS_INVALID_LANGUAGE_CODE', index=10, number=11,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TARGET_ALL_IS_NOT_ALLOWED_FOR_PLACEMENT_IN_SEARCH_CAMPAIGN', index=11, number=12,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIVERSAL_APP_CAMPAIGN_SETTING_DUPLICATE_DESCRIPTION', index=12, number=13,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIVERSAL_APP_CAMPAIGN_SETTING_DESCRIPTION_LINE_WIDTH_TOO_LONG', index=13, number=14,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='UNIVERSAL_APP_CAMPAIGN_SETTING_APP_ID_CANNOT_BE_MODIFIED', index=14, number=15,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_YOUTUBE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN', index=15, number=16,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_IMAGE_MEDIA_IDS_IN_UNIVERSAL_APP_CAMPAIGN', index=16, number=17,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='MEDIA_INCOMPATIBLE_FOR_UNIVERSAL_APP_CAMPAIGN', index=17, number=18,
      serialized_options=None,
      type=None),
    _descriptor.EnumValueDescriptor(
      name='TOO_MANY_EXCLAMATION_MARKS', index=18, number=19,
      serialized_options=None,
      type=None),
  ],
  containing_type=None,
  serialized_options=None,
  serialized_start=144,
  serialized_end=1209,
)
_sym_db.RegisterEnumDescriptor(_SETTINGERRORENUM_SETTINGERROR)


_SETTINGERRORENUM = _descriptor.Descriptor(
  name='SettingErrorEnum',
  full_name='google.ads.googleads.v1.errors.SettingErrorEnum',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
    _SETTINGERRORENUM_SETTINGERROR,
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=123,
  serialized_end=1209,
)

_SETTINGERRORENUM_SETTINGERROR.containing_type = _SETTINGERRORENUM
DESCRIPTOR.message_types_by_name['SettingErrorEnum'] = _SETTINGERRORENUM
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

SettingErrorEnum = _reflection.GeneratedProtocolMessageType('SettingErrorEnum', (_message.Message,), dict(
  DESCRIPTOR = _SETTINGERRORENUM,
  __module__ = 'google.ads.googleads_v1.proto.errors.setting_error_pb2'
  ,
  __doc__ = """Container for enum describing possible setting errors.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v1.errors.SettingErrorEnum)
  ))
_sym_db.RegisterMessage(SettingErrorEnum)


DESCRIPTOR._options = None
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: google/ads/googleads_v2/proto/services/feed_item_target_service.proto

import sys
_b=sys.version_info[0]<3 and (lambda x:x) or (lambda x:x.encode('latin1'))
from google.protobuf import descriptor as _descriptor
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


from google.ads.google_ads.v2.proto.resources import feed_item_target_pb2 as google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2
from google.api import annotations_pb2 as google_dot_api_dot_annotations__pb2
from google.api import client_pb2 as google_dot_api_dot_client__pb2


DESCRIPTOR = _descriptor.FileDescriptor(
  name='google/ads/googleads_v2/proto/services/feed_item_target_service.proto',
  package='google.ads.googleads.v2.services',
  syntax='proto3',
  serialized_options=_b('\n$com.google.ads.googleads.v2.servicesB\032FeedItemTargetServiceProtoP\001ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\242\002\003GAA\252\002 Google.Ads.GoogleAds.V2.Services\312\002 Google\\Ads\\GoogleAds\\V2\\Services\352\002$Google::Ads::GoogleAds::V2::Services'),
  serialized_pb=_b('\nEgoogle/ads/googleads_v2/proto/services/feed_item_target_service.proto\x12 google.ads.googleads.v2.services\x1a>google/ads/googleads_v2/proto/resources/feed_item_target.proto\x1a\x1cgoogle/api/annotations.proto\x1a\x17google/api/client.proto\"1\n\x18GetFeedItemTargetRequest\x12\x15\n\rresource_name\x18\x01 \x01(\t\"\x82\x01\n\x1cMutateFeedItemTargetsRequest\x12\x13\n\x0b\x63ustomer_id\x18\x01 \x01(\t\x12M\n\noperations\x18\x02 \x03(\x0b\x32\x39.google.ads.googleads.v2.services.FeedItemTargetOperation\"}\n\x17\x46\x65\x65\x64ItemTargetOperation\x12\x43\n\x06\x63reate\x18\x01 \x01(\x0b\x32\x31.google.ads.googleads.v2.resources.FeedItemTargetH\x00\x12\x10\n\x06remove\x18\x02 \x01(\tH\x00\x42\x0b\n\toperation\"n\n\x1dMutateFeedItemTargetsResponse\x12M\n\x07results\x18\x02 \x03(\x0b\x32<.google.ads.googleads.v2.services.MutateFeedItemTargetResult\"3\n\x1aMutateFeedItemTargetResult\x12\x15\n\rresource_name\x18\x01 \x01(\t2\xd0\x03\n\x15\x46\x65\x65\x64ItemTargetService\x12\xbd\x01\n\x11GetFeedItemTarget\x12:.google.ads.googleads.v2.services.GetFeedItemTargetRequest\x1a\x31.google.ads.googleads.v2.resources.FeedItemTarget\"9\x82\xd3\xe4\x93\x02\x33\x12\x31/v2/{resource_name=customers/*/feedItemTargets/*}\x12\xd9\x01\n\x15MutateFeedItemTargets\x12>.google.ads.googleads.v2.services.MutateFeedItemTargetsRequest\x1a?.google.ads.googleads.v2.services.MutateFeedItemTargetsResponse\"?\x82\xd3\xe4\x93\x02\x39\"4/v2/customers/{customer_id=*}/feedItemTargets:mutate:\x01*\x1a\x1b\xca\x41\x18googleads.googleapis.comB\x81\x02\n$com.google.ads.googleads.v2.servicesB\x1a\x46\x65\x65\x64ItemTargetServiceProtoP\x01ZHgoogle.golang.org/genproto/googleapis/ads/googleads/v2/services;services\xa2\x02\x03GAA\xaa\x02 Google.Ads.GoogleAds.V2.Services\xca\x02 Google\\Ads\\GoogleAds\\V2\\Services\xea\x02$Google::Ads::GoogleAds::V2::Servicesb\x06proto3')
  ,
  dependencies=[google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2.DESCRIPTOR,google_dot_api_dot_annotations__pb2.DESCRIPTOR,google_dot_api_dot_client__pb2.DESCRIPTOR,])




_GETFEEDITEMTARGETREQUEST = _descriptor.Descriptor(
  name='GetFeedItemTargetRequest',
  full_name='google.ads.googleads.v2.services.GetFeedItemTargetRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.GetFeedItemTargetRequest.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=226,
  serialized_end=275,
)


_MUTATEFEEDITEMTARGETSREQUEST = _descriptor.Descriptor(
  name='MutateFeedItemTargetsRequest',
  full_name='google.ads.googleads.v2.services.MutateFeedItemTargetsRequest',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='customer_id', full_name='google.ads.googleads.v2.services.MutateFeedItemTargetsRequest.customer_id', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='operations', full_name='google.ads.googleads.v2.services.MutateFeedItemTargetsRequest.operations', index=1,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=278,
  serialized_end=408,
)


_FEEDITEMTARGETOPERATION = _descriptor.Descriptor(
  name='FeedItemTargetOperation',
  full_name='google.ads.googleads.v2.services.FeedItemTargetOperation',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='create', full_name='google.ads.googleads.v2.services.FeedItemTargetOperation.create', index=0,
      number=1, type=11, cpp_type=10, label=1,
      has_default_value=False, default_value=None,
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
    _descriptor.FieldDescriptor(
      name='remove', full_name='google.ads.googleads.v2.services.FeedItemTargetOperation.remove', index=1,
      number=2, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
    _descriptor.OneofDescriptor(
      name='operation', full_name='google.ads.googleads.v2.services.FeedItemTargetOperation.operation',
      index=0, containing_type=None, fields=[]),
  ],
  serialized_start=410,
  serialized_end=535,
)


_MUTATEFEEDITEMTARGETSRESPONSE = _descriptor.Descriptor(
  name='MutateFeedItemTargetsResponse',
  full_name='google.ads.googleads.v2.services.MutateFeedItemTargetsResponse',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='results', full_name='google.ads.googleads.v2.services.MutateFeedItemTargetsResponse.results', index=0,
      number=2, type=11, cpp_type=10, label=3,
      has_default_value=False, default_value=[],
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=537,
  serialized_end=647,
)


_MUTATEFEEDITEMTARGETRESULT = _descriptor.Descriptor(
  name='MutateFeedItemTargetResult',
  full_name='google.ads.googleads.v2.services.MutateFeedItemTargetResult',
  filename=None,
  file=DESCRIPTOR,
  containing_type=None,
  fields=[
    _descriptor.FieldDescriptor(
      name='resource_name', full_name='google.ads.googleads.v2.services.MutateFeedItemTargetResult.resource_name', index=0,
      number=1, type=9, cpp_type=9, label=1,
      has_default_value=False, default_value=_b("").decode('utf-8'),
      message_type=None, enum_type=None, containing_type=None,
      is_extension=False, extension_scope=None,
      serialized_options=None, file=DESCRIPTOR),
  ],
  extensions=[
  ],
  nested_types=[],
  enum_types=[
  ],
  serialized_options=None,
  is_extendable=False,
  syntax='proto3',
  extension_ranges=[],
  oneofs=[
  ],
  serialized_start=649,
  serialized_end=700,
)

_MUTATEFEEDITEMTARGETSREQUEST.fields_by_name['operations'].message_type = _FEEDITEMTARGETOPERATION
_FEEDITEMTARGETOPERATION.fields_by_name['create'].message_type = google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2._FEEDITEMTARGET
_FEEDITEMTARGETOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMTARGETOPERATION.fields_by_name['create'])
_FEEDITEMTARGETOPERATION.fields_by_name['create'].containing_oneof = _FEEDITEMTARGETOPERATION.oneofs_by_name['operation']
_FEEDITEMTARGETOPERATION.oneofs_by_name['operation'].fields.append(
  _FEEDITEMTARGETOPERATION.fields_by_name['remove'])
_FEEDITEMTARGETOPERATION.fields_by_name['remove'].containing_oneof = _FEEDITEMTARGETOPERATION.oneofs_by_name['operation']
_MUTATEFEEDITEMTARGETSRESPONSE.fields_by_name['results'].message_type = _MUTATEFEEDITEMTARGETRESULT
DESCRIPTOR.message_types_by_name['GetFeedItemTargetRequest'] = _GETFEEDITEMTARGETREQUEST
DESCRIPTOR.message_types_by_name['MutateFeedItemTargetsRequest'] = _MUTATEFEEDITEMTARGETSREQUEST
DESCRIPTOR.message_types_by_name['FeedItemTargetOperation'] = _FEEDITEMTARGETOPERATION
DESCRIPTOR.message_types_by_name['MutateFeedItemTargetsResponse'] = _MUTATEFEEDITEMTARGETSRESPONSE
DESCRIPTOR.message_types_by_name['MutateFeedItemTargetResult'] = _MUTATEFEEDITEMTARGETRESULT
_sym_db.RegisterFileDescriptor(DESCRIPTOR)

GetFeedItemTargetRequest = _reflection.GeneratedProtocolMessageType('GetFeedItemTargetRequest', (_message.Message,), dict(
  DESCRIPTOR = _GETFEEDITEMTARGETREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_item_target_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedItemTargetService.GetFeedItemTarget][google.ads.googleads.v2.services.FeedItemTargetService.GetFeedItemTarget].
  
  
  Attributes:
      resource_name:
          The resource name of the feed item targets to fetch.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.GetFeedItemTargetRequest)
  ))
_sym_db.RegisterMessage(GetFeedItemTargetRequest)

MutateFeedItemTargetsRequest = _reflection.GeneratedProtocolMessageType('MutateFeedItemTargetsRequest', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMTARGETSREQUEST,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_item_target_service_pb2'
  ,
  __doc__ = """Request message for
  [FeedItemTargetService.MutateFeedItemTargets][google.ads.googleads.v2.services.FeedItemTargetService.MutateFeedItemTargets].
  
  
  Attributes:
      customer_id:
          The ID of the customer whose feed item targets are being
          modified.
      operations:
          The list of operations to perform on individual feed item
          targets.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateFeedItemTargetsRequest)
  ))
_sym_db.RegisterMessage(MutateFeedItemTargetsRequest)

FeedItemTargetOperation = _reflection.GeneratedProtocolMessageType('FeedItemTargetOperation', (_message.Message,), dict(
  DESCRIPTOR = _FEEDITEMTARGETOPERATION,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_item_target_service_pb2'
  ,
  __doc__ = """A single operation (create, remove) on an feed item target.
  
  
  Attributes:
      operation:
          The mutate operation.
      create:
          Create operation: No resource name is expected for the new
          feed item target.
      remove:
          Remove operation: A resource name for the removed feed item
          target is expected, in this format:  ``customers/{customer_id}
          /feedItemTargets/{feed_id}~{feed_item_id}~{feed_item_target_ty
          pe}~{feed_item_target_id}``
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.FeedItemTargetOperation)
  ))
_sym_db.RegisterMessage(FeedItemTargetOperation)

MutateFeedItemTargetsResponse = _reflection.GeneratedProtocolMessageType('MutateFeedItemTargetsResponse', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMTARGETSRESPONSE,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_item_target_service_pb2'
  ,
  __doc__ = """Response message for an feed item target mutate.
  
  
  Attributes:
      results:
          All results for the mutate.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateFeedItemTargetsResponse)
  ))
_sym_db.RegisterMessage(MutateFeedItemTargetsResponse)

MutateFeedItemTargetResult = _reflection.GeneratedProtocolMessageType('MutateFeedItemTargetResult', (_message.Message,), dict(
  DESCRIPTOR = _MUTATEFEEDITEMTARGETRESULT,
  __module__ = 'google.ads.googleads_v2.proto.services.feed_item_target_service_pb2'
  ,
  __doc__ = """The result for the feed item target mutate.
  
  
  Attributes:
      resource_name:
          Returned for successful operations.
  """,
  # @@protoc_insertion_point(class_scope:google.ads.googleads.v2.services.MutateFeedItemTargetResult)
  ))
_sym_db.RegisterMessage(MutateFeedItemTargetResult)


DESCRIPTOR._options = None

_FEEDITEMTARGETSERVICE = _descriptor.ServiceDescriptor(
  name='FeedItemTargetService',
  full_name='google.ads.googleads.v2.services.FeedItemTargetService',
  file=DESCRIPTOR,
  index=0,
  serialized_options=_b('\312A\030googleads.googleapis.com'),
  serialized_start=703,
  serialized_end=1167,
  methods=[
  _descriptor.MethodDescriptor(
    name='GetFeedItemTarget',
    full_name='google.ads.googleads.v2.services.FeedItemTargetService.GetFeedItemTarget',
    index=0,
    containing_service=None,
    input_type=_GETFEEDITEMTARGETREQUEST,
    output_type=google_dot_ads_dot_googleads__v2_dot_proto_dot_resources_dot_feed__item__target__pb2._FEEDITEMTARGET,
    serialized_options=_b('\202\323\344\223\0023\0221/v2/{resource_name=customers/*/feedItemTargets/*}'),
  ),
  _descriptor.MethodDescriptor(
    name='MutateFeedItemTargets',
    full_name='google.ads.googleads.v2.services.FeedItemTargetService.MutateFeedItemTargets',
    index=1,
    containing_service=None,
    input_type=_MUTATEFEEDITEMTARGETSREQUEST,
    output_type=_MUTATEFEEDITEMTARGETSRESPONSE,
    serialized_options=_b('\202\323\344\223\0029\"4/v2/customers/{customer_id=*}/feedItemTargets:mutate:\001*'),
  ),
])
_sym_db.RegisterServiceDescriptor(_FEEDITEMTARGETSERVICE)

DESCRIPTOR.services_by_name['FeedItemTargetService'] = _FEEDITEMTARGETSERVICE

# @@protoc_insertion_point(module_scope)
